summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/codegenerators/javacodeclassfielddeclarationblock.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/codegenerators/javacodeclassfielddeclarationblock.cpp')
-rw-r--r--umbrello/umbrello/codegenerators/javacodeclassfielddeclarationblock.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/umbrello/umbrello/codegenerators/javacodeclassfielddeclarationblock.cpp b/umbrello/umbrello/codegenerators/javacodeclassfielddeclarationblock.cpp
index 520f5611..5507c314 100644
--- a/umbrello/umbrello/codegenerators/javacodeclassfielddeclarationblock.cpp
+++ b/umbrello/umbrello/codegenerators/javacodeclassfielddeclarationblock.cpp
@@ -27,8 +27,8 @@
// Constructors/Destructors
//
-JavaCodeClassFieldDeclarationBlock::JavaCodeClassFieldDeclarationBlock ( CodeClassField * tqparent )
- : CodeClassFieldDeclarationBlock ( tqparent )
+JavaCodeClassFieldDeclarationBlock::JavaCodeClassFieldDeclarationBlock ( CodeClassField * parent )
+ : CodeClassFieldDeclarationBlock ( parent )
{
setOverallIndentationLevel(1);
updateContent();
@@ -77,7 +77,7 @@ void JavaCodeClassFieldDeclarationBlock::updateContent( )
break;
default:
case CodeGenerationPolicy::FromParent:
// do nothing here... will leave as from tqparent object
break;
}
}
@@ -101,7 +101,7 @@ void JavaCodeClassFieldDeclarationBlock::updateContent( )
} else {
// FIX?: IF a constructor method exists in the classifiercodedoc
// of the tqparent Object, then we can use that instead (if its empty).
if(cf->fieldIsSingleValue())
{
if(!typeName.isEmpty())
@@ -77,7 +77,7 @@ void JavaCodeClassFieldDeclarationBlock::updateContent( )
default:
case CodeGenerationPolicy::FromParent:
- // do nothing here... will leave as from tqparent object
+ // do nothing here... will leave as from parent object
break;
}
@@ -101,7 +101,7 @@ void JavaCodeClassFieldDeclarationBlock::updateContent( )
} else {
// FIX?: IF a constructor method exists in the classifiercodedoc
- // of the tqparent Object, then we can use that instead (if its empty).
+ // of the parent Object, then we can use that instead (if its empty).
if(cf->fieldIsSingleValue())
{